@@ -1,3 +1,7 @@
+package Net::FTP::Backup;
+
+our $Location;
+
 use AppConfig qw(:argcount);
 use Data::Dumper;
 use File::Find;
@@ -17,21 +21,23 @@ sub cleanup {
     cleanup and die "$lockfile must be removed before running script";
 
 my $config = AppConfig->new( {CASE => 1} ) ;
-my $rl     = 'rsync_Location';
+my $rl     = 'Location';
 
 $config->define($rl, { ARGCOUNT => ARGCOUNT_LIST });
-$config->file($ENV{FTP_RSYNC});
+$config->file($ENV{NET_FTP_BACKUP});
 
 my $dir = $config->get($rl);
-my  $W  = 'rsync-files-wanted.dat';
-open W, ">$W" or die "cannot open $W: $!";
 
 warn Dumper($dir);
 
-find(\&wanted, @$dir);
+foreach (@$dir) {
+  $Location = $_;
+  find(\&wanted, $_);
+}
 
 sub unwanted {
     my $file = shift;
+
     return 1 if $file =~ /.DS_Store/;
     return 1 if $file =~ /.FBC/;
     return 1 if $file =~ /\.mp3$/;
@@ -39,14 +45,20 @@ sub unwanted {
 
 sub wanted {
 
-    last unless -f;
+  last unless -f; 
+
+  if ($Location = '/Users/metaperl') {
+    # do not enter subdirs for home dir
+    last unless $File::Find::dir eq $Location;
+  }
+
     last if /[\r\n]/s;
     
     my $lf = $_;
 
     last if unwanted($File::Find::name);
 
-    print W "$File::Find::name\n";
+    print $File::Find::name, $/;
 
 }
 
